| Title: | Models for Simulating Wolf Populations |
|---|---|
| Description: | Simulate the dynamic of wolf populations using a specific Individual-Based Model (IBM) compiled in C, see Chapron et al. (2016) <doi:10.1016/j.ecolmodel.2016.08.012>. |
| Authors: | Guillaume Chapron [aut, cre], Camilla Wikenros [ctb], Olof Liberg [ctb], Øystein Flagstad [ctb], Cyril Milleret [ctb], Johan Månsson [ctb], Linn Svensson [ctb], Barbara Zimmermann [ctb], Mikael Åkesson [ctb], Petter Wabakken [ctb], Håkan Sand [ctb] |
| Maintainer: | Guillaume Chapron <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0 |
| Built: | 2026-05-22 18:48:49 UTC |
| Source: | https://github.com/cran/pop.wolf |
A package to run simulations of wolf populations using an Individual-Based Model compiled in C. The model is parameterized with data from the Scandinavian wolf population.
| Package: | pop.wolf |
| Type: | Package |
| Version: | 0.1 |
| Date: | 2015-12-23 |
| License: | GPL-3 |
Guillaume Chapron <[email protected]> with contributions from Camilla Wikenros, Olof Liberg, Øystein Flagstad, Cyril Milleret, Johan Månsson, Linn Svensson, Barbara Zimmermann, Mikael Åkesson, Petter Wabakken and Håkan Sand.
Plot population projections
plot_projection(projection, title)plot_projection(projection, title)
projection |
A list obtained after running the function |
title |
A string indicating which variable should be plotted ( |
Plot average projections with 95% confidence interval.
No returned value, plot created
oldpar <- par(mfrow = c(1,1)) projection <- project( years = 12, runs = 100, surv_pup = c(0.65, 0.1), surv_sub = c(0.74, 0.13), surv_vag = c(0.42, 0.1), surv_adt = c(0.82, 0.03), dispers_weib_shape = c(1.419, 0.154), dispers_weib_scale = c(4.687, 0.528), settl_weib_shape = c(1.353, 0.210), settl_weib_scale = c(4.606, 0.772), pair1breed = c(0.79, 0.05), litter_size = c(5, 0.52) ) par(mfrow=c(2,2)) plot_projection(projection, "Packs") plot_projection(projection, "Pairs") plot_projection(projection, "Reproductions") plot_projection(projection, "Population") par(oldpar)oldpar <- par(mfrow = c(1,1)) projection <- project( years = 12, runs = 100, surv_pup = c(0.65, 0.1), surv_sub = c(0.74, 0.13), surv_vag = c(0.42, 0.1), surv_adt = c(0.82, 0.03), dispers_weib_shape = c(1.419, 0.154), dispers_weib_scale = c(4.687, 0.528), settl_weib_shape = c(1.353, 0.210), settl_weib_scale = c(4.606, 0.772), pair1breed = c(0.79, 0.05), litter_size = c(5, 0.52) ) par(mfrow=c(2,2)) plot_projection(projection, "Packs") plot_projection(projection, "Pairs") plot_projection(projection, "Reproductions") plot_projection(projection, "Population") par(oldpar)
Run stochastic wolf population projections.
project(years, runs, surv_pup, surv_sub, surv_vag, surv_adt, dispers_weib_shape, dispers_weib_scale, settl_weib_shape, settl_weib_scale, pair1breed, litter_size, pop_initial, pop_quota, seed)project(years, runs, surv_pup, surv_sub, surv_vag, surv_adt, dispers_weib_shape, dispers_weib_scale, settl_weib_shape, settl_weib_scale, pair1breed, litter_size, pop_initial, pop_quota, seed)
years |
A number: number of years to project the population. |
runs |
A number: number of times (or Monte Carlo runs) to project the population. |
surv_pup |
A vector: average and standard deviation of annual survival of pups from 0 to 5 months. |
surv_sub |
A vector: average and standard deviation of annual survival of subadults (>5 month-old non breeding animals in packs). |
surv_vag |
A vector: average and standard deviation of annual survival of vagrants. |
surv_adt |
A vector: average and standard deviation of survival of resident adults. |
dispers_weib_shape |
A vector: average and standard deviation of the shape of a Weibul distributed variable describing the time in months until dispersal. |
dispers_weib_scale |
A vector: average and standard deviation of the scale of a Weibul distributed variable describing the time in months until dispersal. |
settl_weib_shape |
A vector: average and standard deviation of the shape of a Weibul distributed variable describing the time in months from dispersal until settlement. |
settl_weib_scale |
A vector: average and standard deviation of the scale of a Weibul distributed variable describing the time in months from dispersal until settlement. |
pair1breed |
Number of times (or Monte Carlo runs) to project the population. |
litter_size |
A vector: average and standard deviation of number of pups in litter. |
pop_initial |
(optional) A list: with elements packs and vagrants. |
pop_quota |
(optional) An array: number of animals killed every month (rows) from the following categories (columns): pairs, alphas, vagrants, subadults, unknown. Removing a pair kills 2 animals but is coded as 1. |
seed |
(optional) A number: seed of the random number generator. |
Run stochastic wolf population projections with an Individual-Based Model (IBM) compiled in C.
runs |
a 3-dimensional array of numbers of individuals with dimension c(years, statistics, runs) |
individuals |
a 2-dimensional array of individuals events |
parameters |
a list of parameters of the projection |
# Number of years to project years <- 15 # Initial population pop_initial <- list() # 10 packs of size 5 with alpha male aged 2 and alpha female aged 3 pop_initial$packs <- matrix(rep(c(2,3,5),10), ncol=3, nrow=10, byrow=TRUE) # 5 vagrants pop_initial$vagrants <- 5 # Hunting quota pop_quota <- matrix(0, nrow=12*years+1, ncol=5) # Hunt 4 alphas every March pop_quota[1+seq(3,years*12,12),2] <- 4 projection <- project( years = years, runs = 100, surv_pup = c(0.65, 0.1), surv_sub = c(0.74, 0.13), surv_vag = c(0.42, 0.1), surv_adt = c(0.82, 0.03), dispers_weib_shape = c(1.419, 0.154), dispers_weib_scale = c(4.687, 0.528), settl_weib_shape = c(1.353, 0.210), settl_weib_scale = c(4.606, 0.772), pair1breed = c(0.79, 0.05), litter_size = c(5, 0.52), pop_initial = pop_initial, pop_quota = pop_quota, seed = 1 )# Number of years to project years <- 15 # Initial population pop_initial <- list() # 10 packs of size 5 with alpha male aged 2 and alpha female aged 3 pop_initial$packs <- matrix(rep(c(2,3,5),10), ncol=3, nrow=10, byrow=TRUE) # 5 vagrants pop_initial$vagrants <- 5 # Hunting quota pop_quota <- matrix(0, nrow=12*years+1, ncol=5) # Hunt 4 alphas every March pop_quota[1+seq(3,years*12,12),2] <- 4 projection <- project( years = years, runs = 100, surv_pup = c(0.65, 0.1), surv_sub = c(0.74, 0.13), surv_vag = c(0.42, 0.1), surv_adt = c(0.82, 0.03), dispers_weib_shape = c(1.419, 0.154), dispers_weib_scale = c(4.687, 0.528), settl_weib_shape = c(1.353, 0.210), settl_weib_scale = c(4.606, 0.772), pair1breed = c(0.79, 0.05), litter_size = c(5, 0.52), pop_initial = pop_initial, pop_quota = pop_quota, seed = 1 )